# Generated by Django 3.2 on 2023-02-16 04:25

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
    ]

    operations = [
        migrations.CreateModel(
            name='Log',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('ip_address', models.CharField(max_length=255)),
                ('latitude', models.FloatField()),
                ('longitude', models.FloatField()),
                ('model', models.CharField(blank=True, max_length=255, null=True)),
                ('action', models.CharField(blank=True, max_length=255, null=True)),
                ('field_id', models.IntegerField(blank=True, null=True)),
                ('timestamp', models.DateTimeField(auto_now_add=True)),
                ('username', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to=settings.AUTH_USER_MODEL)),
            ],
        ),
    ]



from django.shortcuts import render, get_object_or_404, redirect, HttpResponseRedirect
from django.contrib.auth.decorators import login_required
from contract.models import Contract, EmpSalary, EmpPlacement
from settings_app.decorators import allowed_users
from log.models import Log
import datetime
from attendance.models import Month
from settings_app.utils import f_monthname
def get_years():
    current_year = datetime.datetime.now().year
    return [year for year in range(2022, current_year + 1)]

@login_required
def LogList(request):
    objects = []
    page = ''
    monthname = ''
    year = None
    years = get_years()
    months = Month.objects.all()
    curYear = datetime.datetime.now().year
    curMonth = datetime.datetime.now().month
    if request.method == 'POST':
        getYear = request.POST.get('tinan')
        getMonth = request.POST.get('fulan')
        if getYear != '0' and getMonth != '0':
            page = 'filter'
            monthname = f_monthname(int(getMonth))
            year = int(getYear)
            obj = Log.objects.filter(timestamp__year=getYear)
            for j in obj:
                if j.timestamp.month == int(getMonth):
                    objects.append(j)
        elif getMonth != '0':
            page = 'filter'
            year = int(curYear)
            monthname = f_monthname(int(getMonth))
            obj = Log.objects.filter(timestamp__year=curYear)
            for j in obj:
                if j.timestamp.month == int(getMonth):
                    objects.append(j)
        elif getYear != '0':
            page = 'filter'
            year = int(getYear)
            monthname = f_monthname(int(curMonth))
            obj = Log.objects.filter(timestamp__year=curYear)
            for j in obj:
                if j.timestamp.month == int(curMonth):
                    objects.append(j)
        else:
            data = Log.objects.all().order_by('-pk')
            for i in data:
                objects.append(i)
    else:
        data = Log.objects.all().order_by('-pk')
        for i in data:
            objects.append(i)
    context = {
        'title': 'Log List', 'legend': 'Log List',
        'objects': objects, 'monthname':monthname, 'year':year,
        'years': years, 'months': months, 'page': page
    }
    return render(request,'log/list.html', context)

@login_required
def LogDetail(request, hashid):
    objects = Log.objects.get(hashed=hashid)
    context = {
        'title': 'Log Detail', 'legend': 'Log Detail',
        'objects': objects
    }
    return render(request,'log/detail.html', context)


# Generated by Django 3.2 on 2023-02-23 14:56

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('log', '0008_alter_log_ip_type'),
    ]

    operations = [
        migrations.RenameField(
            model_name='log',
            old_name='ip_type',
            new_name='is_private',
        ),
    ]



# Generated by Django 3.2 on 2023-02-23 02:03

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('log', '0003_auto_20230223_1048'),
    ]

    operations = [
        migrations.AddField(
            model_name='log',
            name='priv_address',
            field=models.CharField(blank=True, max_length=255, null=True),
        ),
    ]



from django.db import models
from django.contrib.auth.models import User

class Log(models.Model):
    username = models.ForeignKey(User, on_delete=models.SET_NULL, null=True, blank=True)
    ip_address = models.CharField(max_length=255)
    is_private = models.BooleanField(default=False, null=True, blank=True)
    priv_address = models.CharField(max_length=255, null=True, blank=True)
    latitude = models.FloatField(null=True, blank=True)
    longitude = models.FloatField(null=True, blank=True)
    model = models.CharField(max_length=255, blank=True, null=True)
    action = models.CharField(max_length=255, blank=True, null=True)
    device = models.CharField(max_length=255, blank=True, null=True)
    field_id = models.IntegerField(null=True, blank=True)
    country = models.CharField(max_length=255, blank=True, null=True)
    city = models.CharField(max_length=255, blank=True, null=True)
    isp = models.CharField(max_length=255, blank=True, null=True)
    timestamp = models.DateTimeField(auto_now_add=True)
    hashed = models.CharField(max_length=32, null=True)

    def __str__(self):
        template = '{0.username} - {0.model} - {0.ip_address} - {0.priv_address}'
        return template.format(self)
    



# Generated by Django 3.2 on 2023-02-23 14:55

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('log', '0007_log_ip_type'),
    ]

    operations = [
        migrations.AlterField(
            model_name='log',
            name='ip_type',
            field=models.BooleanField(blank=True, default=False, null=True),
        ),
    ]



from django.utils import timezone
from .models import Log

from settings_app.utils import getnewid
from ipware import get_client_ip


def log_action(request, model, action, field_id ):

    # work: WORK ON HERE
    client_ip, is_routable = get_client_ip(request)
    if client_ip is None :
        client_ip = "0.0.0.0"
    else:
        if is_routable:
            ipv = "Public"
        else:
            ipv = "Private"

    try:
        country = 'Unknown'
        lat = 'Unknown'
        lon = 'Unknown'
        city = 'Unknown'
    except:
        country = 'Unknown'
        city = 'Unknown'
        lat = None
        lon = None

    new_client_ip_address = request.META.get('HTTP_X_FORWARDED_FOR') or request.META.get('REMOTE_ADDR')    
    newid, new_hashid = getnewid(Log)
    Log.objects.create(
        pk = newid,
        username=request.user,
        ip_address=new_client_ip_address,
        is_private=is_routable,
        priv_address = client_ip,
        latitude=lat,
        longitude=lon,
        country=country,
        city=city,
        model=model,
        action=action,
        field_id=field_id,
        timestamp=timezone.now(),
        hashed=new_hashid
    )



# Generated by Django 3.2 on 2023-02-23 00:29

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('log', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='log',
            name='latitude',
            field=models.FloatField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='log',
            name='longitude',
            field=models.FloatField(blank=True, null=True),
        ),
    ]
